SyncOperation

Enum SyncOperation 

pub enum SyncOperation {
Show 22 variants GetDatabases(GenericCallback<BackendResult<Vec<DatabaseInfo>>>, ImmutableOrigin), UpgradeVersion(GenericSender<BackendResult<u64>>, ImmutableOrigin, String, u64, u64), GetObjectStore(GenericSender<BackendResult<IndexedDBObjectStore>>, ImmutableOrigin, String, String), Commit(GenericCallback<TxnCompleteMsg>, ImmutableOrigin, String, u64), Abort(GenericCallback<TxnCompleteMsg>, ImmutableOrigin, String, u64), UpgradeTransactionFinished { origin: ImmutableOrigin, db_name: String, txn: u64, committed: bool, }, RequestHandled { origin: ImmutableOrigin, db_name: String, txn: u64, request_id: u64, }, CreateTransaction { sender: GenericSender<BackendResult<u64>>, origin: ImmutableOrigin, db_name: String, mode: IndexedDBTxnMode, scope: Vec<String>, }, TxnMaybeCommit { origin: ImmutableOrigin, db_name: String, txn: u64, }, TransactionFinished { origin: ImmutableOrigin, db_name: String, txn: u64, }, CreateIndex(ImmutableOrigin, String, String, String, KeyPath, bool, bool), DeleteIndex(ImmutableOrigin, String, String, String), CreateObjectStore(GenericSender<BackendResult<CreateObjectResult>>, ImmutableOrigin, String, String, Option<KeyPath>, bool), DeleteObjectStore(GenericSender<BackendResult<()>>, ImmutableOrigin, String, String), CloseDatabase(ImmutableOrigin, Uuid, String), OpenDatabase(GenericCallback<ConnectionMsg>, ImmutableOrigin, String, Option<u64>, Uuid), DeleteDatabase(GenericCallback<BackendResult<u64>>, ImmutableOrigin, String, Uuid), Version(GenericSender<BackendResult<u64>>, ImmutableOrigin, String), AbortPendingUpgrades { pending_upgrades: HashMap<String, HashSet<Uuid>>, origin: ImmutableOrigin, }, AbortPendingUpgrade { name: String, id: Uuid, origin: ImmutableOrigin, }, NotifyEndOfVersionChange { id: Uuid, name: String, old_version: u64, origin: ImmutableOrigin, }, Exit(GenericSender<()>),
}

Variants



GetDatabases(GenericCallback<BackendResult<Vec<DatabaseInfo>>>, ImmutableOrigin)

Gets existing databases.



UpgradeVersion(GenericSender<BackendResult<u64>>, ImmutableOrigin, String, u64, u64)

Upgrades the version of the database

Tuple Fields

0: GenericSender<BackendResult<u64>>

Sender to send new version as the result of the operation



GetObjectStore(GenericSender<BackendResult<IndexedDBObjectStore>>, ImmutableOrigin, String, String)

Get object store info



Commit(GenericCallback<TxnCompleteMsg>, ImmutableOrigin, String, u64)

Commits changes of a transaction to the database



Abort(GenericCallback<TxnCompleteMsg>, ImmutableOrigin, String, u64)

Aborts a transaction in the backend



UpgradeTransactionFinished

Upgrade transaction finished after its event was fired in script.

Fields

db_name: String
txn: u64
committed: bool


RequestHandled

<https://w3c.github.io/IndexedDB/#transaction-lifetime Step 3: When each request associated with a transaction is processed, a success or error event will be fired. While the event is being dispatched, the transaction state is set to active, allowing additional requests to be made against the transaction. Once the event dispatch is complete, the transaction’s state is set to inactive again.

Fields

db_name: String
txn: u64
request_id: u64


CreateTransaction



TxnMaybeCommit

Request script to recheck transaction commit eligibility.

Fields

db_name: String
txn: u64


TransactionFinished

Fields

db_name: String
txn: u64


CreateIndex(ImmutableOrigin, String, String, String, KeyPath, bool, bool)

Creates a new index for the database



DeleteIndex(ImmutableOrigin, String, String, String)

Delete an index



CreateObjectStore(GenericSender<BackendResult<CreateObjectResult>>, ImmutableOrigin, String, String, Option<KeyPath>, bool)

Creates a new store for the database



DeleteObjectStore(GenericSender<BackendResult<()>>, ImmutableOrigin, String, String)



CloseDatabase(ImmutableOrigin, Uuid, String)



OpenDatabase(GenericCallback<ConnectionMsg>, ImmutableOrigin, String, Option<u64>, Uuid)



DeleteDatabase(GenericCallback<BackendResult<u64>>, ImmutableOrigin, String, Uuid)

Deletes the database



Version(GenericSender<BackendResult<u64>>, ImmutableOrigin, String)

Returns the version of the database



AbortPendingUpgrades

Abort pending database upgrades

Fields

pending_upgrades: HashMap<String, HashSet<Uuid>>


AbortPendingUpgrade

Abort the current pending upgrade.

Fields

name: String
id: Uuid


NotifyEndOfVersionChange

Fields

id: Uuid
name: String
old_version: u64


Exit(GenericSender<()>)

Send a reply when done cleaning up thread resources and then shut it down